@@ -138,23 +138,29 @@ class GFFDatabase:
     A set of GFF entries from a GFF file.
     """
     def __init__(self, from_filename=None,
-                 reverse_recs=False):
+                 reverse_recs=False,
+                 include_introns=False,
+                 suppress_warnings=False):
 	self.genes = []
 	self.mRNAs = []
 	self.exons = []
 	self.cdss = []
         self.__entries = []
 	self.from_filename = from_filename
+        self.suppress_warnings = suppress_warnings
 
         ## Indexed representation of GFFs
         self.mRNAs_by_gene = defaultdict(list)
         self.exons_by_mRNA = defaultdict(list)
         self.cdss_by_exon = defaultdict(list)
 
+        self.suppress_warnings = suppress_warnings
+
 	if from_filename:
 	    # load GFF from given filename
 	    self.from_file(from_filename,
-                           reverse_recs=reverse_recs)
+                           reverse_recs=reverse_recs,
+                           include_introns=include_introns)
 	    self.from_filename = from_filename
             
     def __len(self):
@@ -162,7 +168,8 @@ class GFFDatabase:
 
 
     def from_file(self, filename, version="3",
-                  reverse_recs=False):
+                  reverse_recs=False,
+                  include_introns=False):
         FILE = open(filename, "r")
         reader = Reader(FILE, version)
         for record in reader.read_recs(reverse_recs=reverse_recs):
@@ -175,6 +182,10 @@ class GFFDatabase:
 	    elif record.type == "exon":
 		self.exons.append(record)
                 self.exons_by_mRNA[record.get_parent()].append(record)
+            elif include_introns and (record.type == "intron"):
+                # Treat introns like exons if asked to
+                self.exons.append(record)
+                self.exons_by_mRNA[record.get_parent()].append(record)
 	    elif record.type == "CDS":
 		self.cdss.append(record)
                 self.cdss_by_exon[record.get_parent()].append(record)
@@ -236,8 +247,9 @@ class GFFDatabase:
 			cdss.append(cds_rec)
                         
 	    if len(mRNAs) == len(exons) == len(cdss) == 0:
-                print "WARNING: No entries found for gene %s in GFF %s" \
-                      %(gene, self.from_filename)
+                if not self.suppress_warnings:
+                    print "WARNING: No entries found for gene %s in GFF %s" \
+                          %(gene, self.from_filename)
                 # Remove from gene hierarchy
                 del gene_hierarchy[gene]
 #		raise Exception, "No entries found for gene %s in GFF: %s" %(gene,
