@@ -9,6 +9,8 @@ import sys
 import subprocess
 from collections import defaultdict
 
+import pysam
+
 import misopy.gff_utils as gff_utils
 import misopy.as_events as as_events
 import misopy.run_miso as run_miso
@@ -20,6 +22,7 @@ from misopy.settings import miso_path as miso_settings_path
 import misopy.cluster_utils as cluster_utils
 
 miso_path = os.path.dirname(os.path.abspath(__file__))
+manual_url = "http://genes.mit.edu/burgelab/miso/docs/"
 
 class GenesDispatcher:
     """
@@ -33,7 +36,9 @@ class GenesDispatcher:
                  use_cluster=False,
                  chunk_jobs=200,
                  SGEarray=False,
-                 sge_job_name="misojob"):
+                 sge_job_name="misojob",
+                 gene_ids=None,
+                 num_proc=None):
         self.threads = {}
         self.gff_dir = gff_dir
         self.bam_filename = bam_filename
@@ -48,7 +53,9 @@ class GenesDispatcher:
             print "Are you sure your BAM file is indexed?"
         self.output_dir = output_dir
         self.read_len = read_len
-        self.overhang_len = overhang_len
+        # For now setting overhang to 1 always
+        #self.overhang_len = overhang_len
+        self.overhang_len = 1
         self.settings_fname = settings_fname
         self.paired_end = paired_end
         self.use_cluster = use_cluster
@@ -62,6 +69,10 @@ class GenesDispatcher:
             self.chunk_jobs = 200
         self.SGEarray = SGEarray
         self.num_processors = Settings.get_num_processors()
+        if num_proc is not None:
+            num_proc = int(num_proc)
+            self.num_processors = num_proc
+            print "Using %d processors" %(num_proc)
         self.long_thresh = 50
         self.batch_logs_dir = \
             os.path.join(output_dir, "batch-logs")
@@ -80,6 +91,11 @@ class GenesDispatcher:
         # filenames
         self.gene_ids_to_gff_index = \
             gff_utils.get_gene_ids_to_gff_index(gff_dir)
+        # If we're given filtered gene IDs, use them
+        if gene_ids is not None:
+            self.gene_ids = gene_ids
+        else:
+            self.gene_ids = self.gene_ids_to_gff_index.keys()
         self.batch_filenames = self.output_batch_files()
 
 
@@ -92,14 +108,13 @@ class GenesDispatcher:
         """
         batch_filenames = []
         chunk_jobs = self.chunk_jobs
-        all_gene_ids = self.gene_ids_to_gff_index.keys()
-        num_genes = len(all_gene_ids)
+        num_genes = len(self.gene_ids)
         num_chunks = max(1, int(round(num_genes / float(chunk_jobs))))
         if not self.use_cluster:
             # When not using cluster, use local multi-cores
             # using default number of processors
             num_chunks = self.num_processors
-        gene_ids_batches = cluster_utils.chunk_list(all_gene_ids,
+        gene_ids_batches = cluster_utils.chunk_list(self.gene_ids,
                                                     num_chunks)
         for batch_num, gene_ids_batch in enumerate(gene_ids_batches):
             batch_size = len(gene_ids_batch)
@@ -289,6 +304,112 @@ def get_ids_passing_filter(gff_index_dir,
     return ids_passing_filter
             
 
+def check_gff_and_bam(gff_dir, bam_filename,
+                      num_genes=10000,
+                      num_reads=10000):
+    """
+    Look for chromosome headers mismatches between input GFF
+    annotation and BAM filename.  Warn users if there are
+    headers mismatches.
+    """
+    print "Checking your GFF annotation and BAM for mismatches..."
+    # Check that BAM exists
+    if not os.path.isfile(bam_filename):
+        print "Error: BAM %s cannot be found." %(bam_filename)
+        return
+    # Check that a BAM header is available
+    bam_index_fname = "%s.bai" %(bam_filename)
+    if not os.path.isfile(bam_index_fname):
+        print "WARNING: Expected BAM index file %s not found." \
+            %(bam_index_fname)
+        print "Are you sure your BAM file is indexed?"
+    print "Checking if BAM has mixed read lengths..."
+    bam_file = pysam.Samfile(bam_filename, "rb")
+    n = 0
+    seq_lens = {}
+    for bam_read in bam_file:
+        # Check more of the reads for mixed read lengths
+        if n >= (num_reads * 10):
+            break
+        seq_lens[len(bam_read.seq)] = True
+        n += 1
+    all_seq_lens = seq_lens.keys()
+    if len(all_seq_lens) > 1:
+        print "\nWARNING: Found mixed length reads in your BAM file! " \
+              "MISO does not support mixed read lengths. Please " \
+              "trim your reads to a uniform length and re-run " \
+              "or run MISO separately on each read length. " \
+              "Proceeding anyway, though it is likely that this will " \
+              "result in errors or inability to match reads to " \
+              "your annotation."
+        print "Read lengths were: %s" %(",".join(all_seq_lens))
+        time.sleep(15)
+    else:
+        print "Found reads of length %d in BAM." %(all_seq_lens[0])
+    genes_fname = os.path.join(gff_dir, "genes.gff")
+    if not os.path.isfile(genes_fname):
+        # No genes.gff found - warn user and abort headers check
+        print "WARNING: No genes.gff file found in %s. Did you index "\
+              "your GFF with an older version of MISO?" \
+              %(gff_dir)
+        return
+    # Read first few genes chromosomes
+    gff_chroms = {}
+    gff_starts_with_chr = False
+    with open(genes_fname) as genes:
+        n = 0
+        for line in genes:
+            if n >= num_genes:
+                break
+            curr_gff_chrom = line.strip().split("\t")[0]
+            gff_chroms[curr_gff_chrom] = True
+            # Record that GFF chroms start with chr if they do
+            if curr_gff_chrom.startswith("chr"):
+                gff_starts_with_chr = True
+            n += 1
+    # Read first few BAM reads chromosomes
+    bam_file = pysam.Samfile(bam_filename, "rb")
+    bam_chroms = {}
+    bam_starts_with_chr = False
+    n = 0
+    for bam_read in bam_file:
+        if n >= num_reads:
+            break
+        read_chrom = bam_file.getrname(bam_read.tid)
+        bam_chroms[read_chrom] = True
+        if str(read_chrom).startswith("chr"):
+            bam_starts_with_chr = True
+        n += 1
+    mismatch_found = False
+    if bam_starts_with_chr != gff_starts_with_chr:
+        mismatch_found = True
+    if mismatch_found:
+        print "\nWARNING: It looks like your GFF annotation file and your BAM " \
+              "file might not have matching headers (chromosome names.) " \
+              "If this is the case, your run will fail as no reads from " \
+              "the BAM could be matched up with your annotation."
+        print "\nPlease see:\n\t%s\n for more information." %(manual_url)
+        # Default: assume BAM starts with chr headers
+        chr_containing = "BAM file (%s)" %(bam_filename)
+        not_chr_containing = "GFF annotation (%s)" %(gff_dir)
+        if not bam_starts_with_chr:
+            # BAM does not start with chr, GFF does
+            chr_containing, not_chr_containing = \
+                not_chr_containing, chr_containing
+        print "It looks like your %s contains \'chr\' chromosomes (UCSC-style) " \
+              "while your %s does not." %(chr_containing,
+                                          not_chr_containing)
+        print "\nThe first few BAM chromosomes were: "
+        print ",".join(bam_chroms.keys())
+        print "BAM references: "
+        print bam_file.references
+        print "The first few GFF chromosomes were: "
+        print ",".join(gff_chroms.keys())
+        print "\nRun is likely to fail or produce empty output. Proceeding " \
+              "anyway...\n"
+        time.sleep(15)
+        
+
 def compute_all_genes_psi(gff_dir, bam_filename, read_len, output_dir,
                           use_cluster=False,
                           SGEarray=False,
@@ -297,6 +418,7 @@ def compute_all_genes_psi(gff_dir, bam_filename, read_len, output_dir,
                           paired_end=None,
                           settings_fname=None,
                           job_name="misojob",
+                          num_proc=None,
                           prefilter=False):
     """
     Compute Psi values for genes using a GFF and a BAM filename.
@@ -308,17 +430,22 @@ def compute_all_genes_psi(gff_dir, bam_filename, read_len, output_dir,
       Uses bedtools to determine coverage of each event and remove
       events that do not meet the coverage criteria from the run.
     """
-    print "Computing gene-level Psi for genes..." 
+    print "Computing Psi values..." 
     print "  - GFF index: %s" %(gff_dir)
     print "  - BAM: %s" %(bam_filename)
     print "  - Read length: %d" %(read_len)
     print "  - Output directory: %s" %(output_dir)
 
     misc_utils.make_dir(output_dir)
+
+    # Check GFF and BAM for various errors like headers mismatch
+    check_gff_and_bam(gff_dir, bam_filename)
     
     # Prefilter events that do not meet the coverage criteria
     # If filtering is on, only run on events that meet
     # the filter.
+    all_gene_ids = None
+    
     if prefilter:
         print "  - Prefiltering on"
         if misc_utils.which("bedtools") is None:
@@ -360,8 +487,11 @@ def compute_all_genes_psi(gff_dir, bam_filename, read_len, output_dir,
                                  use_cluster=use_cluster,
                                  chunk_jobs=chunk_jobs,
                                  sge_job_name=job_name,
-                                 SGEarray=SGEarray)
+                                 SGEarray=SGEarray,
+                                 gene_ids=all_gene_ids,
+                                 num_proc=num_proc)
     dispatcher.run()
+
             
 def output_gene_ids_in_batches(gene_ids_to_gff_index,
                                output_dir,
@@ -376,7 +506,6 @@ def output_gene_ids_in_batches(gene_ids_to_gff_index,
     """
     for gene_id in gene_ids_to_gff_index:
         indeed_filename = gene_ids_to_gff_index[gene_id]
-        
     pass
 
     
@@ -521,6 +650,10 @@ def main():
                       "be processed or distributed to jobs if MISO is run on a "
                       "cluster. This options requires bedtools to be installed and "
                       "available on path.")
+    parser.add_option("-p", dest="num_proc", default=None, nargs=1,
+                      help="Number of processors to use. Only applies when running " \
+                      "MISO on a single machine with multiple cores; does not apply " \
+                      "to runs submitted to cluster with --use-cluster.")
     (options, args) = parser.parse_args()
 
     greeting()
@@ -588,7 +721,8 @@ def main():
                               chunk_jobs=options.chunk_jobs,
                               paired_end=options.paired_end,
                               settings_fname=settings_filename,
-                              prefilter=options.prefilter)
+                              prefilter=options.prefilter,
+                              num_proc=options.num_proc)
 
             
 		    
