@@ -7,3 +7,7 @@ MISO_START_LINEAR=4L
 # stop after fixed no. iterations
 MISO_STOP_FIXEDNO=0L
 MISO_STOP_CONVERGENT_MEAN=1L
+# various algorithms
+MISO_ALGO_REASSIGN=0L
+MISO_ALGO_MARGINAL=1L
+MISO_ALGO_CLASSES=2L
