@@ -403,7 +403,7 @@ int splicing_paired_assignment_matrix(const splicing_gff_t *gff, size_t gene,
     SPLICING_CHECK(splicing_vector_init(&vfragmentProb, 0));
     SPLICING_FINALLY(splicing_vector_destroy, &vfragmentProb);
     SPLICING_CHECK(splicing_normal_fragment(normalMean, normalVar, numDevs,
-					    2*readLength, myfragmentProb, 
+					    readLength, myfragmentProb, 
 					    &fragmentStart));
     splicing_vector_scale(myfragmentProb, 
 			  1.0/splicing_vector_sum(myfragmentProb));
@@ -627,7 +627,7 @@ int splicing_paired_assignment_matrix_old(const splicing_gff_t *gff, size_t gene
     SPLICING_CHECK(splicing_vector_init(&vfragmentProb, 0));
     SPLICING_FINALLY(splicing_vector_destroy, &vfragmentProb);
     SPLICING_CHECK(splicing_normal_fragment(normalMean, normalVar, numDevs,
-					    2*readLength, myfragmentProb, 
+					    readLength, myfragmentProb, 
 					    &fragmentStart));
     splicing_vector_scale(myfragmentProb, 
 			  1.0/splicing_vector_sum(myfragmentProb));
